# Generated by roxygen2: do not edit by hand

export(CalibrateSingleDetermination)
export(FindPosteriorMeanRate)
export(FindPredictiveCalendarAgeDensity)
export(FindSummedProbabilityDistribution)
export(GenerateOxcalCode)
export(InterpolateCalibrationCurve)
export(PPcalibrate)
export(PlotCalendarAgeDensityIndividualSample)
export(PlotConvergenceData)
export(PlotGelmanRubinDiagnosticMultiChain)
export(PlotGelmanRubinDiagnosticSingleChain)
export(PlotNumberOfClusters)
export(PlotNumberOfInternalChanges)
export(PlotPosteriorChangePoints)
export(PlotPosteriorHeights)
export(PlotPosteriorMeanRate)
export(PlotPredictiveCalendarAgeDensity)
export(PlotRateIndividualRealisation)
export(PolyaUrnBivarDirichlet)
export(WalkerBivarDirichlet)
useDynLib(carbondate, .registration = TRUE)
